USE paper_library_db;

-- ----------------------------
-- Table structure for basic_attachment
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_attachment` (
        `id` bigint NOT NULL COMMENT '主键',
        `school_id` bigint DEFAULT NULL COMMENT '学校id',
        `org_id` bigint DEFAULT NULL COMMENT '机构id',
        `name` varchar(100) NOT NULL COMMENT '文件名',
        `type` varchar(10) NOT NULL COMMENT '文件类型',
        `size` int NOT NULL COMMENT '单位（KB）',
        `md5` varchar(32) NOT NULL COMMENT '文件md5值',
        `path` varchar(2000) NOT NULL COMMENT '存储路径',
        `create_id` bigint DEFAULT NULL COMMENT '创建人',
        `create_time` bigint DEFAULT NULL COMMENT '创建时间',
        `update_id` bigint DEFAULT NULL COMMENT '更新人',
        `update_time` bigint DEFAULT NULL COMMENT '更新时间',
        `obj_id` bigint DEFAULT NULL COMMENT '关联业务id',
        PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='所有附件记录表';


-- ----------------------------
-- Table structure for basic_exam
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_exam` (
          `id` bigint NOT NULL,
          `school_id` bigint NOT NULL,
          `semester_id` bigint NOT NULL COMMENT '学期ID',
          `name` varchar(32) NOT NULL COMMENT '类型名称',
          `create_id` bigint DEFAULT NULL COMMENT '创建人',
          `create_time` bigint DEFAULT NULL COMMENT '创建时间',
          `update_id` bigint DEFAULT NULL COMMENT '更新人',
          `update_time` bigint DEFAULT NULL COMMENT '更新时间',
          PRIMARY KEY (`id`) USING BTREE,
          KEY `idx_1` (`semester_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='档案类型表';

-- ----------------------------
-- Table structure for basic_message
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_message` (
             `id` bigint NOT NULL COMMENT '主键',
             `school_id` bigint DEFAULT NULL COMMENT '学校id',
             `org_id` bigint DEFAULT NULL COMMENT '机构id',
             `user_id` bigint NOT NULL COMMENT '消息接收人用户',
             `user_name` varchar(100) DEFAULT NULL COMMENT '用户名称',
             `mobile_number` varchar(11) DEFAULT NULL COMMENT '电话号码',
             `paper_number` varchar(50) DEFAULT NULL COMMENT '试卷编号',
             `course_code` varchar(50) DEFAULT NULL COMMENT '课程代码',
             `message_type` varchar(45) DEFAULT NULL COMMENT '消息类型',
             `business_operate` varchar(45) NOT NULL COMMENT '业务操作',
             `business_id` bigint DEFAULT NULL COMMENT '业务id',
             `template_code` varchar(45) NOT NULL COMMENT '消息模板代码',
             `variable_params` text COMMENT '变量参数内容',
             `template_content` mediumtext COMMENT '模板内容',
             `send_status` varchar(45) DEFAULT NULL COMMENT '消息发送状态',
             `send_result` varchar(200) DEFAULT NULL COMMENT '消息发送结果',
             `remark` text COMMENT '备注',
             `create_id` bigint DEFAULT NULL COMMENT '创建人',
             `create_time` bigint DEFAULT NULL COMMENT '创建时间',
             `update_id` bigint DEFAULT NULL COMMENT '更新人',
             `update_time` bigint DEFAULT NULL COMMENT '更新时间',
             `resend_count` int DEFAULT NULL COMMENT '重试次数',
             PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for basic_operation_log
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_operation_log` (
               `id` bigint NOT NULL COMMENT 'id',
               `detail` mediumtext NOT NULL COMMENT '日志详情',
               `level` varchar(32) DEFAULT NULL COMMENT '日志等级（PRIMARY("一级日志：敏感信息"),SECONDARY("二级日志：重要信息"),TERTIARY("三级日志：次要信息"),QUATERNARY("四级日志：普通信息")）',
               `operation_type` varchar(32) DEFAULT NULL COMMENT '操作类型（UN_KNOW("未知"),SELECT("查询"),EDIT("新增或更新"),DELETE("删除")）',
               `operation_unit` varchar(32) DEFAULT NULL COMMENT '操作对象（略）',
               `system_type` varchar(32) DEFAULT NULL COMMENT '日志系统类型',
               `url` varchar(64) DEFAULT NULL COMMENT '请求地址url',
               `clazz_name` varchar(64) DEFAULT NULL COMMENT '类名称',
               `method` varchar(64) DEFAULT NULL COMMENT '方法名称',
               `args` mediumtext COMMENT '参数',
               `run_time` bigint DEFAULT NULL COMMENT '方法运行时间',
               `run_status` varchar(32) DEFAULT NULL COMMENT '方法运行状态',
               `return_value` mediumtext COMMENT '方法返回值',
               `user_id` bigint NOT NULL COMMENT '用户对象id',
               `user_name` varchar(32) DEFAULT NULL COMMENT '用户名称',
               `create_time` bigint DEFAULT NULL COMMENT '日志记录时间',
               PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='基础日志记录表';

-- ----------------------------
-- Table structure for basic_school
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_school` (
            `id` bigint NOT NULL COMMENT '主键',
            `code` varchar(20) NOT NULL COMMENT '学校编码',
            `name` varchar(100) DEFAULT NULL COMMENT '学校名称',
            `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，false：停用，true：启用',
            `access_key` varchar(50) DEFAULT NULL COMMENT '访问key',
            `access_secret` varchar(50) DEFAULT NULL COMMENT '访问秘钥',
            `remark` text COMMENT '备注',
            `create_id` bigint DEFAULT NULL COMMENT '创建人',
            `create_time` bigint DEFAULT NULL COMMENT '创建时间',
            `update_id` bigint DEFAULT NULL COMMENT '更新人',
            `update_time` bigint DEFAULT NULL COMMENT '更新时间',
            `logo` text COMMENT '学校logo',
            PRIMARY KEY (`id`) USING BTREE,
            UNIQUE KEY `code` (`code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='学校表';

-- ----------------------------
-- Table structure for basic_semester
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_semester` (
              `id` bigint NOT NULL COMMENT '主键',
              `school_id` bigint NOT NULL COMMENT '学校id',
              `name` varchar(100) NOT NULL COMMENT '学期名称',
              `code` varchar(100) DEFAULT NULL COMMENT '学期编码',
              `enable` tinyint DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
              `create_id` bigint DEFAULT NULL COMMENT '创建人id',
              `create_time` bigint DEFAULT NULL COMMENT '创建时间',
              `update_id` bigint DEFAULT NULL COMMENT '更新人id',
              `update_time` bigint DEFAULT NULL COMMENT '更新时间',
              PRIMARY KEY (`id`) USING BTREE,
              UNIQUE KEY `semester_schoolId_name_idx` (`school_id`,`name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='学期字典表';

-- ----------------------------
-- Table structure for basic_verify_code
-- ----------------------------
CREATE TABLE IF NOT EXISTS `basic_verify_code` (
                 `id` bigint NOT NULL COMMENT '主键',
                 `school_id` bigint DEFAULT NULL COMMENT '学校id',
                 `org_id` bigint DEFAULT NULL COMMENT '机构id',
                 `user_id` bigint NOT NULL COMMENT '用户ID',
                 `mobile_number` varchar(11) NOT NULL COMMENT '手机号',
                 `expire_time` bigint NOT NULL COMMENT '到期时间',
                 `valid_period` int NOT NULL COMMENT '单位（分）',
                 `verify_code` varchar(4) NOT NULL COMMENT '4位数字',
                 `create_id` bigint DEFAULT NULL COMMENT '创建人',
                 `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                 `update_id` bigint DEFAULT NULL COMMENT '更新人',
                 `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                 PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='短信验证码记录表';

-- ----------------------------
-- Table structure for exam_course
-- ----------------------------
CREATE TABLE IF NOT EXISTS `exam_course` (
               `exam_id` bigint NOT NULL COMMENT '考试ID',
               `course_code` varchar(45) NOT NULL COMMENT '课程代码',
               `course_name` varchar(100) DEFAULT NULL COMMENT '课程名称',
               PRIMARY KEY (`exam_id`, `course_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for exam_student
-- ----------------------------
CREATE TABLE IF NOT EXISTS `exam_student` (
                `id` bigint NOT NULL COMMENT '学生id',
                `school_id` bigint NOT NULL COMMENT '学校id',
                `semester_id` bigint DEFAULT NULL COMMENT '学期ID',
                `exam_id` bigint DEFAULT NULL COMMENT '考试ID',
                `course_code` varchar(45) DEFAULT NULL COMMENT '课程代码',
                `course_name` varchar(100) DEFAULT NULL COMMENT '课程名称',
                `student_name` varchar(64) NOT NULL COMMENT '学生姓名',
                `student_code` varchar(64) NOT NULL COMMENT '学生编号',
                `college_name` varchar(64) DEFAULT NULL COMMENT '学院名称',
                `major_name` varchar(64) DEFAULT NULL COMMENT '专业',
                `class_name` varchar(64) CHARACTER SET utf8mb4 COLLATE utf8mb4_0900_ai_ci DEFAULT NULL COMMENT '行政班',
                `teacher` varchar(45) DEFAULT NULL COMMENT '任课老师',
                `teach_class` varchar(45) DEFAULT NULL COMMENT '教学班',
                `exam_room` varchar(45) DEFAULT NULL COMMENT '考场',
                `score` double DEFAULT NULL COMMENT '成绩',
                `remark` varchar(200) DEFAULT NULL COMMENT '备注',
                `enable` tinyint DEFAULT '1' COMMENT '可用状态（1：可用，0：不可用）',
                `source` tinyint(1) DEFAULT '0' COMMENT '是否绑定时自动创建：0-导入或者新建，1-绑定时自动创建',
                `bind_count` int DEFAULT NULL DEFAULT 0 COMMENT '绑定图片张数',
                `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                PRIMARY KEY (`id`) USING BTREE,
                UNIQUE KEY `idx_1` (`exam_id`,`course_code`,`student_code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='学校id';

-- ----------------------------
-- Table structure for paper_library
-- ----------------------------
CREATE TABLE IF NOT EXISTS `paper_library` (
             `id` bigint NOT NULL COMMENT '主键',
             `paper_scan_task_id` bigint NOT NULL COMMENT '扫描任务Id',
             `path` varchar(2000) NOT NULL COMMENT '存储路径',
             `student_id` bigint DEFAULT NULL COMMENT '考生ID',
             `sequence` int DEFAULT NULL COMMENT '图片序号',
             `bind_result` varchar(200) CHARACTER SET utf8mb4 COLLATE utf8mb4_0900_ai_ci DEFAULT NULL COMMENT 'OCR或者条码识别结果使用值',
             `recognize_result` mediumtext CHARACTER SET utf8mb4 COLLATE utf8mb4_0900_ai_ci COMMENT 'OCR或者条码识别结果(原始值)',
             `create_id` bigint DEFAULT NULL COMMENT '创建人',
             `create_time` bigint DEFAULT NULL COMMENT '创建时间',
             `update_id` bigint DEFAULT NULL COMMENT '更新人',
             `update_time` bigint DEFAULT NULL COMMENT '更新时间',
             PRIMARY KEY (`id`) USING BTREE,
             KEY `idx_1` (`paper_scan_task_id`,`student_id`),
             KEY `idx_2` (`student_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='其它文件库';

-- ----------------------------
-- Table structure for paper_library_other
-- ----------------------------
CREATE TABLE IF NOT EXISTS `paper_library_other` (
               `id` bigint NOT NULL COMMENT '主键',
               `paper_scan_task_id` bigint NOT NULL COMMENT '扫描任务Id',
               `path` varchar(2000) NOT NULL COMMENT '存储路径',
               `sequence` int DEFAULT NULL COMMENT '图片序号',
               `create_id` bigint DEFAULT NULL COMMENT '创建人',
               `create_time` bigint DEFAULT NULL COMMENT '创建时间',
               `update_id` bigint DEFAULT NULL COMMENT '更新人',
               `update_time` bigint DEFAULT NULL COMMENT '更新时间',
               PRIMARY KEY (`id`) USING BTREE,
               KEY `idx_1` (`paper_scan_task_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='图片库';

-- ----------------------------
-- Table structure for paper_scan_task
-- ----------------------------
CREATE TABLE IF NOT EXISTS `paper_scan_task` (
           `id` bigint NOT NULL,
           `school_id` bigint DEFAULT NULL COMMENT '学校ID',
           `exam_id` bigint NOT NULL COMMENT '考试ID',
           `scan_task_code` varchar(45) DEFAULT NULL COMMENT '任务编号',
           `scan_task_name` varchar(64) NOT NULL COMMENT '扫描任务名称',
           `course_code` varchar(45) DEFAULT NULL COMMENT '课程代码',
           `course_name` varchar(64) DEFAULT NULL COMMENT '课程名称',
           `recognition_type` varchar(45) DEFAULT NULL COMMENT '识别方式（条码、OCR、无）',
           `store_type` varchar(45) DEFAULT NULL COMMENT '存储方式（按课程、按考场、按考点）',
           `student_count` int DEFAULT '0' COMMENT '扫描量（份）',
           `scan_student_count` int DEFAULT '0' COMMENT '扫描学生数量',
           `scan_count` int DEFAULT '0' COMMENT '扫描数量',
           `enable` tinyint(1) DEFAULT '0' COMMENT '任务是否已关闭（1-是，0-否）',
           `create_id` bigint DEFAULT NULL COMMENT '创建人',
           `create_time` bigint DEFAULT NULL COMMENT '创建时间',
           `update_id` bigint DEFAULT NULL COMMENT '更新人',
           `update_time` bigint DEFAULT NULL COMMENT '更新时间',
           PRIMARY KEY (`id`) USING BTREE,
           KEY `idx_1` (`exam_id`,`course_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='扫描任务表';

-- ----------------------------
-- Table structure for sys_org
-- ----------------------------
CREATE TABLE IF NOT EXISTS `sys_org` (
           `id` bigint NOT NULL COMMENT '主键',
           `school_id` bigint NOT NULL COMMENT '学校id',
           `type` varchar(50) DEFAULT NULL COMMENT '类型，SCHOOL：学校，COLLEGE：学院，FACULTY：院系，TEACHING_ROOM：教研室，PRINTING_HOUSE：印刷厂',
           `code` varchar(20) DEFAULT NULL COMMENT '机构代码',
           `name` varchar(100) NOT NULL COMMENT '机构名称',
           `parent_id` bigint DEFAULT NULL COMMENT '上级机构id',
           `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
           `create_id` bigint DEFAULT NULL COMMENT '创建人',
           `create_time` bigint DEFAULT NULL COMMENT '创建时间',
           `update_id` bigint DEFAULT NULL COMMENT '修改人',
           `update_time` bigint DEFAULT NULL COMMENT '修改时间',
           `historic_name` varchar(100) DEFAULT NULL COMMENT '历史机构名称',
           PRIMARY KEY (`id`) USING BTREE,
           UNIQUE KEY `org_schoolId_name_idx` (`school_id`,`name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='学校组织架构';

-- ----------------------------
-- Table structure for sys_privilege
-- ----------------------------
CREATE TABLE IF NOT EXISTS `sys_privilege` (
             `id` bigint NOT NULL COMMENT '主键',
             `name` varchar(100) NOT NULL COMMENT '菜单名称',
             `url` varchar(100) NOT NULL COMMENT 'URL地址',
             `type` varchar(50) NOT NULL COMMENT '类型，MENU：菜单，BUTTON：按钮，LINK：链接，URL：接口地址，LIST：列表，CONDITION：查询条件，TAB：选项卡',
             `parent_id` bigint DEFAULT NULL COMMENT '上级菜单',
             `sequence` int NOT NULL COMMENT '序号',
             `property` varchar(30) DEFAULT NULL COMMENT '属性，NO_AUTH：无需鉴权，AUTH：鉴权，SYS：系统公用',
             `related` text COMMENT '关联属性，type为URL且property为AUTH才有',
             `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
             `default_auth` tinyint DEFAULT '1' COMMENT '默认权限，0：否，1：是',
             `front_display` tinyint(1) DEFAULT '1' COMMENT '是否前端展示',
             PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='菜单权限表';

-- ----------------------------
-- Records of sys_privilege
-- ----------------------------
BEGIN;
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (1, '基础配置', 'base', 'MENU', NULL, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (2, '用户管理', 'user', 'MENU', 1, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (4, '组织架构', 'OrganizationManage', 'MENU', 2, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (5, '用户管理', 'UserManage', 'MENU', 2, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (6, '角色管理', 'RoleManage', 'MENU', 2, 3, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (7, '权限管理', 'MenuManage', 'MENU', 129, 6, NULL, NULL, 0, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (8, '系统管理', 'data', 'MENU', 1, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (9, '考试管理', 'ExamManage', 'MENU', 8, 3, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (10, '列表', 'List', 'LIST', 9, 1, 'AUTH', '15', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (11, '新增', 'Add', 'BUTTON', 9, 2, 'AUTH', '16', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (12, '编辑', 'Edit', 'LINK', 9, 3, 'AUTH', '16', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (13, '查询条件', 'Condition', 'LINK', 9, 4, 'AUTH', '15', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (14, '删除', 'Delete', 'LINK', 9, 5, 'AUTH', '18', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (15, '查询接口', '/api/admin/basic/exam/page', 'URL', 9, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (16, '新增/编辑接口', '/api/admin/basic/exam/save', 'URL', 9, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (17, '删除接口', '/api/admin/basic/exam/delete', 'URL', 9, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (18, '文档管理', 'doc', 'MENU', 1, 4, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (20, '考生管理', 'StudentManage', 'MENU', 8, 4, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (21, '列表', 'List', 'LIST', 20, 1, 'AUTH', '29', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (22, '查询条件', 'Condition', 'CONDITION', 20, 2, 'AUTH', '29', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (23, '新增', 'Add', 'BUTTON', 20, 4, 'AUTH', '30', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (24, '编辑', 'Edit', 'LINK', 20, 5, 'AUTH', '30', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (25, '批量删除', 'BatchDelete', 'BUTTON', 20, 6, 'AUTH', '31', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (26, '导入考生', 'Import', 'BUTTON', 20, 7, 'AUTH', '32', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (27, '删除', 'Delete', 'LINK', 20, 8, 'AUTH', '31', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (28, '查询', 'Select', 'BUTTON', 20, 3, 'AUTH', '29', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (29, '查询接口', '/api/admin/exam/student/page', 'URL', 20, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (30, '新增/编辑接口', '/api/admin/exam/student/save', 'URL', 20, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (31, '删除接口', '/api/admin/exam/student/delete', 'URL', 20, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (32, '导入接口', '/api/admin/exam/student/import', 'URL', 20, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (50, '查询条件-学期', '/api/admin/common/semester/query', 'URL', 149, 8, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (51, '查询条件-考试', '/api/admin/common/exam/query', 'URL', 149, 8, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (54, '查询条件-课程', '/api/admin/common/course/query', 'URL', 149, 12, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (57, '查询条件-学院/专业/班级级联查询', '/api/admin/common/college_major_class/query', 'URL', 149, 15, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (70, '异步任务查询', '/api/admin/data/t_b_task/query', 'URL', 149, 9, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (77, '查询', '/api/admin/sys/user/list', 'URL', 5, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (78, '新增/修改', '/api/admin/sys/user/save', 'URL', 5, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (79, '启用/禁用', '/api/admin/sys/user/enable', 'URL', 5, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (80, '重置密码', '/api/admin/sys/user/reset_password', 'URL', 5, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (81, '导入用户', '/api/admin/sys/user/import', 'URL', 5, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (82, '绑定角色', '/api/admin/sys/user/bind_roles', 'URL', 5, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (83, '查询', '/api/admin/sys/role/list', 'URL', 6, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (84, '删除', '/api/admin/sys/role/remove', 'URL', 6, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (85, '新增/修改', '/api/admin/sys/role/save', 'URL', 6, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (86, '启用/禁用', '/api/admin/sys/role/enable', 'URL', 6, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (87, '用户已绑定角色列表', '/api/admin/sys/role/get_user_roles', 'URL', 5, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (88, '查询', '/api/admin/sys/privilege/list', 'URL', 7, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (89, '新增/修改', '/api/admin/sys/privilege/save', 'URL', 7, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (90, '删除', '/api/admin/sys/privilege/remove', 'URL', 7, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (91, '角色已绑定权限列表', '/api/admin/sys/privilege/get_role_privileges', 'URL', 6, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (92, '查询', '/api/admin/sys/org/list', 'URL', 4, 1, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (93, '新增/修改', '/api/admin/sys/org/save', 'URL', 4, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (94, '删除', '/api/admin/sys/org/remove', 'URL', 4, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (95, '启用/禁用', '/api/admin/sys/org/enable', 'URL', 4, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (111, '扫描管理', 'scanTask', 'MENU', 1, 3, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (129, '公共接口', 'common', 'MENU', NULL, 11, NULL, NULL, 0, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (130, '用户登录相关', 'login', 'MENU', 129, 1, NULL, NULL, 0, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (131, '用户登录', '/api/admin/common/login', 'URL', 130, 1, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (132, '查询用户权限', '/api/admin/common/get_menu', 'URL', 130, 2, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (133, '发送验证码', '/api/admin/common/get_verify_code', 'URL', 130, 3, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (134, '修改密码', '/api/admin/sys/user/update_password', 'URL', 130, 4, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (135, '用户登出', '/api/admin/common/logout', 'URL', 130, 5, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (136, '模糊查询', 'query', 'MENU', 129, 2, NULL, NULL, 0, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (144, '文件相关', 'file', 'MENU', 129, 3, NULL, NULL, 0, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (145, '文件上传', '/api/admin/common/file/upload', 'URL', 144, 1, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (146, '文件查询', '/api/admin/common/file/get_one', 'URL', 144, 2, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (147, '文件下载', '/api/admin/common/file/download', 'URL', 144, 3, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (148, '文件预览', '/api/admin/common/file/preview', 'URL', 144, 4, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (149, '系统相关', 'sys', 'MENU', 129, 4, NULL, NULL, 0, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (150, '查询枚举类型', '/api/admin/common/get_enums', 'URL', 149, 1, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (151, '查询学校列表', '/api/admin/common/school/list', 'URL', 149, 2, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (152, '查询系统参数', '/api/admin/common/sys_config/get_one', 'URL', 149, 3, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (153, '根据学校代码查询学校信息', '/api/admin/common/school/query_by_school_code', 'URL', 149, 4, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (154, '其他', 'other', 'MENU', 129, 5, NULL, NULL, 0, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (155, '用户导入（异步）', '/api/admin/sys/user/async/import', 'URL', 154, 1, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (156, '用户导出', '/api/admin/sys/user/export', 'URL', 154, 2, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (179, '查询考务规则', '/api/admin/basic/exam_rule/list', 'URL', 149, 5, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (180, '查询可设置权限列表', '/api/admin/sys/privilege/list_auth', 'URL', 6, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (181, '超管中心', 'admin', 'MENU', 129, 7, NULL, NULL, 0, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (184, '查询用户可绑定角色', '/api/admin/sys/role/list_to_user', 'URL', 5, 7, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (185, '删除', 'Delete', 'LINK', 5, 6, 'AUTH', '186', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (186, '删除', '/api/admin/sys/user/remove', 'URL', 5, 8, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (195, '获取服务器时间', '/api/admin/common/get_system_time', 'URL', 129, 2, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (200, '扫描端', 'client', 'MENU', NULL, 1, NULL, '202,203,204', 1, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (201, '客户端登录', '/api/admin/client/user/login', 'URL', 200, 1, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (202, '任务查询', '/api/admin/client/task/get', 'URL', 200, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (203, '上传图片', '/api/admin/client/picture/upload', 'URL', 200, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (204, '上传其它图片', '/api/admin/client/other/upload', 'URL', 200, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (217, '查询', 'Select', 'BUTTON', 5, 1, 'AUTH', '77', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (218, '新增用户', 'Add', 'BUTTON', 5, 2, 'AUTH', '78', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (219, '编辑', 'Edit', 'LINK', 5, 1, 'AUTH', '78', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (220, '启用&禁用', 'Enable', 'LINK', 5, 2, 'AUTH', '79', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (221, '列表', 'List', 'LIST', 5, 1, 'AUTH', '77', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (222, '查询条件', 'Condition', 'CONDITION', 5, 1, 'AUTH', '184,87', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (223, '重置密码', 'Reset', 'LINK', 5, 3, 'AUTH', '80', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (225, '子部门', 'Add', 'LINK', 4, 1, 'AUTH', '93', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (226, '修改', 'Edit', 'LINK', 4, 2, 'AUTH', '93', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (227, '删除', 'Delete', 'LINK', 4, 3, 'AUTH', '94', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (228, '树形列表', 'List', 'LIST', 4, 1, 'AUTH', '92', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (229, '查询', 'Select', 'BUTTON', 6, 1, 'AUTH', '83,88', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (230, '添加角色', 'Add', 'BUTTON', 6, 2, 'AUTH', '85,89', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (231, '编辑', 'Edit', 'LINK', 6, 1, 'AUTH', '83,91', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (232, '删除', 'Delete', 'LINK', 6, 2, 'AUTH', '84,90', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (233, '列表', 'List', 'LIST', 6, 1, 'AUTH', '83', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (234, '查询条件', 'Condition', 'CONDITION', 4, 1, 'AUTH', '92', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (235, '查询条件', 'Condition', 'CONDITION', 6, 1, 'AUTH', '83', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (243, '批量导入', 'Export', 'BUTTON', 5, 3, 'AUTH', '81', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (244, '扫描任务管理', 'ScanTaskManage', 'MENU', 111, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (245, '查询条件', 'Condition', 'CONDITION', 244, 1, 'AUTH', '250', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (246, '列表', 'List', 'LIST', 244, 2, 'AUTH', '250', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (247, '查询', 'Select', 'BUTTON', 244, 3, 'AUTH', '250', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (248, '查看详情', 'ScanTaskDetail', 'LINK', 244, 4, 'AUTH', '251', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (249, '清除数据', 'ClearScanData', 'LINK', 244, 5, 'AUTH', '252', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (250, '查询', '/api/admin/paper/scan_task/page', 'URL', 244, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (251, '查看详情接口', '/api/admin/paper/scan_task/detail', 'URL', 244, 2, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (252, '清除数据接口', '/api/admin/paper/scan_task/clear_data', 'URL', 244, 3, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (260, '文档管理', 'DocumentManage', 'MENU', 18, 1, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (261, '查询条件', 'Condition', 'CONDITION', 260, 1, 'AUTH', '266', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (262, '列表', 'List', 'LIST', 260, 2, 'AUTH', '266', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (263, '查询', 'Select', 'BUTTON', 260, 3, 'AUTH', '266', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (264, '查看详情', 'Detail', 'LINK', 260, 4, 'AUTH', '267,268,269,270,271', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (265, '其它文件详情', 'OtherDetail', 'LINK', 260, 5, 'AUTH', '272', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (266, '查询接口', '/api/admin/paper/document/page', 'URL', 260, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (267, '查看详情接口', '/api/admin/paper/document/detail', 'URL', 260, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (268, '批量下载接口', '/api/admin/paper/document/download', 'URL', 260, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (269, '查询考生图片集合接口', '/api/admin/paper/document/list_student_picture', 'URL', 260, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (270, '查询可绑定考生接口', '/api/admin/paper/document/page_student', 'URL', 260, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (271, '重新绑定接口', '/api/admin/paper/document/rebind', 'URL', 260, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (272, '其它文件详情接口', '/api/admin/paper/document/other_detail', 'URL', 260, 7, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (370, '获取系统编码', '/api/admin/common/get_code', 'URL', 149, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (371, '根据类型查询机构', '/api/admin/sys/org/find_by_type', 'URL', 4, 5, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (409, '系统设置', 'SystemSetting', 'MENU', 8, 1, NULL, '410,411', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (410, '查询', '/api/admin/sys/setting/get', 'URL', 409, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (411, '新增/修改', '/api/admin/sys/setting/save', 'URL', 409, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (412, '查询全局系统设置参数', '/api/admin/sys/setting_global/get', 'URL', 149, 16, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (413, '新增/修改全局系统设置参数', '/api/admin/sys/setting_global/save', 'URL', 149, 17, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (507, '菜单管理', 'MenuManage', 'MENU', 1, 7, NULL, NULL, 1, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (508, '自定义菜单', 'CustomMenu', 'MENU', 507, 1, NULL, NULL, 1, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (510, '学期管理', 'SemesterManage', 'MENU', 8, 2, NULL, NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (511, '新建', 'Add', 'BUTTON', 510, 1, 'AUTH', '534', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (512, '编辑', 'Edit', 'LINK', 510, 1, 'AUTH', '534', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (513, '删除', 'Delete', 'LINK', 510, 2, 'AUTH', '535', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (514, '列表', 'List', 'LIST', 510, 1, 'AUTH', '533', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (527, '查询自定义菜单权限', '/api/admin/menu/custom/list', 'URL', 508, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (528, '学校已绑定自定义菜单权限列表', '/api/admin/menu/custom/get_school_custom_privileges', 'URL', 508, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (529, '学校新增/修改自定义菜单权限', '/api/admin/menu/custom/save', 'URL', 508, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (530, '查询', 'Select', 'BUTTON', 508, 1, 'AUTH', '527,528', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (531, '保存', 'Save', 'BUTTON', 508, 2, 'AUTH', '529', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (533, '查询', '/api/admin/basic/semester/page', 'URL', 510, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (534, '新增/编辑', '/api/admin/basic/semester/save', 'URL', 510, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (535, '删除', '/api/admin/basic/semester/delete', 'URL', 510, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (539, '共用接口-查询字典', '/api/admin/common/get_dictionary', 'URL', 149, 7, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (549, '短信日志', 'SmsManage', 'MENU', 8, 5, NULL, NULL, 1, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (550, '查询', 'Select', 'BUTTON', 549, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (551, '查询', '/api/admin/basic/message/list', 'URL', 550, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (552, '查询短信类型', '/api/admin/basic/message/list_message_types', 'URL', 550, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (553, '短信失败重发', '/api/admin/basic/message/resend', 'URL', 550, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (554, '查询条件', 'Condition', 'CONDITION', 549, 1, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (555, '列表', 'List', 'LIST', 549, 1, 'AUTH', '551,552', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (556, '短信失败重发', 'Send', 'LINK', 549, 1, 'AUTH', '553', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (634, '发送验证码（绑定手机号）', '/api/admin/common/file/exam_paper_upload', 'URL', 130, 3, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (635, '刷新缓存', '/api/admin/common/flush_cache', 'URL', 149, 20, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (647, '成员管理', 'Manager', 'LINK', 6, 3, 'AUTH', '648,649', 1, 0, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (648, '新增/修改', '/api/admin/sys/role/group/save', 'URL', 647, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (649, '查询', '/api/admin/sys/role/group/list', 'URL', 647, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (675, '授权配置', 'AuthManage', 'MENU', 1, 6, NULL, NULL, 1, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (676, '授权配置-导出硬件信息按钮', 'Export', 'BUTTON', 675, 1, 'AUTH', '677,678,679', 1, 0, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (677, '导出硬件信息', '/api/admin/auth/export/device/info', 'URL', 676, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (678, '离线激活', '/api/admin/auth/offline/activation', 'URL', 676, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (679, '查询激活信息', '/api/admin/auth/select', 'URL', 676, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (757, '导入组织架构', '/api/admin/sys/org/import', 'URL', 4, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` (`id`, `name`, `url`, `type`, `parent_id`, `sequence`, `property`, `related`, `enable`, `default_auth`, `front_display`) VALUES (758, '导入组织架构', 'Import', 'BUTTON', 4, 4, 'AUTH', '757', 1, 0, 1);
COMMIT;

-- ----------------------------
-- Table structure for sys_role
-- ----------------------------
CREATE TABLE IF NOT EXISTS `sys_role` (
            `id` bigint NOT NULL COMMENT '主键',
            `school_id` bigint DEFAULT NULL COMMENT '学校id',
            `org_id` bigint DEFAULT NULL COMMENT '机构id',
            `name` varchar(50) NOT NULL COMMENT '角色名称',
            `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
            `type` varchar(20) DEFAULT NULL COMMENT '角色类别，ADMIN：超级管理员，SCHOOL_ADMIN：管理员：EXAM_TEACHER：考务老师，QUESTION_TEACHER：命题老师，CUSTOMER：客服人员，PRINTER：印刷人员，CUSTOM：自定义',
            `create_id` bigint DEFAULT NULL COMMENT '创建人',
            `create_time` bigint DEFAULT NULL COMMENT '创建时间',
            `update_id` bigint DEFAULT NULL COMMENT '修改人',
            `update_time` bigint DEFAULT NULL COMMENT '修改时间',
            `default_role` tinyint NOT NULL DEFAULT '0' COMMENT '是否系统内置角色，1：是，0：不是',
            `source` varchar(100) DEFAULT NULL COMMENT '角色来源，ANALYSIS：教研分析',
            `interpret` text COMMENT '角色说明',
            PRIMARY KEY (`id`) USING BTREE,
            UNIQUE KEY `role_schoolId_name_idx` (`school_id`,`name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='角色表';

-- ----------------------------
-- Records of sys_role
-- ----------------------------
BEGIN;
INSERT INTO `sys_role` (`id`, `school_id`, `org_id`, `name`, `enable`, `type`, `create_id`, `create_time`, `update_id`, `update_time`, `default_role`, `source`, `interpret`) VALUES (1, NULL, NULL, '系统管理员', 1, 'ADMIN', NULL, NULL, NULL, NULL, 1, NULL, '系统内置');
INSERT INTO `sys_role` (`id`, `school_id`, `org_id`, `name`, `enable`, `type`, `create_id`, `create_time`, `update_id`, `update_time`, `default_role`, `source`, `interpret`) VALUES (3, NULL, NULL, '扫描员', 1, 'SCANNER', 1, 1665560162947, 299492059637612544, 1676253646609, 0, NULL, NULL);
INSERT INTO `sys_role` (`id`, `school_id`, `org_id`, `name`, `enable`, `type`, `create_id`, `create_time`, `update_id`, `update_time`, `default_role`, `source`, `interpret`) VALUES (340862842867548160, 1, NULL, '学校管理员', 1, NULL, 1, 1672208834673, 340867663804760064, 1678083685051, 0, NULL, '系统自带');
COMMIT;

-- ----------------------------
-- Table structure for sys_role_group_member
-- ----------------------------
CREATE TABLE IF NOT EXISTS `sys_role_group_member` (
             `id` bigint NOT NULL COMMENT '主键',
             `role_id` bigint NOT NULL COMMENT '角色id',
             `user_id` bigint NOT NULL COMMENT '用户id',
             `member_id` bigint NOT NULL COMMENT '成员id',
             `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
             PRIMARY KEY (`id`) USING BTREE,
             UNIQUE KEY `role_group_roleId_memberId_idx` (`role_id`,`member_id`,`enable`) USING BTREE,
             KEY `role_group_member_idx` (`role_id`,`user_id`,`member_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='角色组成员表';

-- ----------------------------
-- Table structure for sys_role_privilege
-- ----------------------------
CREATE TABLE IF NOT EXISTS `sys_role_privilege` (
              `id` bigint NOT NULL COMMENT '主键',
              `role_id` bigint NOT NULL COMMENT '角色id',
              `privilege_id` bigint NOT NULL COMMENT '菜单id',
              `enable` tinyint DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
              PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='角色和菜单关联表';

-- ----------------------------
-- Records of sys_role_privilege
-- ----------------------------
BEGIN;
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1583366560558071809, 3, 200, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1583366560566460417, 3, 202, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1583366560566460418, 3, 203, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1583366560570654722, 3, 204, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1583366560570654723, 3, 205, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236361121793, 341255305734127616, 1, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236365316097, 341255305734127616, 2, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236365316098, 341255305734127616, 4, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236365316099, 341255305734127616, 5, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236365316100, 341255305734127616, 77, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236365316101, 341255305734127616, 78, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236365316102, 341255305734127616, 79, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236369510401, 341255305734127616, 80, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236369510402, 341255305734127616, 81, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236369510403, 341255305734127616, 87, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236369510404, 341255305734127616, 217, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236369510405, 341255305734127616, 218, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236369510406, 341255305734127616, 219, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236369510407, 341255305734127616, 92, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236373704705, 341255305734127616, 220, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236373704706, 341255305734127616, 93, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236373704707, 341255305734127616, 221, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236373704708, 341255305734127616, 94, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236373704709, 341255305734127616, 222, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236373704710, 341255305734127616, 223, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236373704711, 341255305734127616, 225, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236373704712, 341255305734127616, 226, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236377899010, 341255305734127616, 227, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236377899011, 341255305734127616, 228, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236377899012, 341255305734127616, 234, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236377899013, 341255305734127616, 243, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236377899014, 341255305734127616, 757, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236377899015, 341255305734127616, 758, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236377899016, 341255305734127616, 184, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236377899017, 341255305734127616, 185, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1624957236377899018, 341255305734127616, 186, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423088582657, 340862842867548160, 256, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423105359874, 340862842867548160, 512, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423105359875, 340862842867548160, 1, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423113748482, 340862842867548160, 257, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423113748483, 340862842867548160, 513, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423113748484, 340862842867548160, 2, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423113748485, 340862842867548160, 258, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423113748486, 340862842867548160, 514, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423113748487, 340862842867548160, 259, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423113748488, 340862842867548160, 4, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423117942786, 340862842867548160, 260, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423117942787, 340862842867548160, 5, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423117942788, 340862842867548160, 6, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423122137090, 340862842867548160, 262, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423122137091, 340862842867548160, 263, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423122137092, 340862842867548160, 8, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423122137093, 340862842867548160, 264, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423126331393, 340862842867548160, 9, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423126331394, 340862842867548160, 10, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423126331395, 340862842867548160, 11, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423130525698, 340862842867548160, 267, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423130525699, 340862842867548160, 12, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423130525700, 340862842867548160, 13, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423130525701, 340862842867548160, 14, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423134720002, 340862842867548160, 15, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423134720003, 340862842867548160, 16, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423134720004, 340862842867548160, 17, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423134720005, 340862842867548160, 18, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423138914305, 340862842867548160, 19, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423138914306, 340862842867548160, 20, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423138914307, 340862842867548160, 533, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423138914308, 340862842867548160, 21, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423143108610, 340862842867548160, 534, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423143108611, 340862842867548160, 22, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423143108612, 340862842867548160, 23, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423143108613, 340862842867548160, 535, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423147302914, 340862842867548160, 24, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423147302915, 340862842867548160, 25, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423147302916, 340862842867548160, 26, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423151497218, 340862842867548160, 27, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423151497219, 340862842867548160, 28, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423151497220, 340862842867548160, 29, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423151497221, 340862842867548160, 30, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423155691522, 340862842867548160, 31, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423155691523, 340862842867548160, 32, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423155691524, 340862842867548160, 33, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423159885826, 340862842867548160, 34, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423159885827, 340862842867548160, 35, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423159885828, 340862842867548160, 36, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423159885829, 340862842867548160, 37, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423164080129, 340862842867548160, 549, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423164080130, 340862842867548160, 38, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423164080131, 340862842867548160, 550, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423164080132, 340862842867548160, 551, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423168274433, 340862842867548160, 39, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423168274434, 340862842867548160, 552, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423168274435, 340862842867548160, 40, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423168274436, 340862842867548160, 41, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423168274437, 340862842867548160, 42, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423172468737, 340862842867548160, 554, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423172468738, 340862842867548160, 43, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423172468739, 340862842867548160, 555, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423172468740, 340862842867548160, 44, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423176663041, 340862842867548160, 45, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423176663042, 340862842867548160, 569, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423176663043, 340862842867548160, 570, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423176663044, 340862842867548160, 77, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423176663045, 340862842867548160, 78, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423180857346, 340862842867548160, 79, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423180857347, 340862842867548160, 80, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423180857348, 340862842867548160, 81, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423180857349, 340862842867548160, 83, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423185051650, 340862842867548160, 84, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423185051651, 340862842867548160, 85, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423185051652, 340862842867548160, 87, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423185051653, 340862842867548160, 88, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423189245954, 340862842867548160, 89, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423189245955, 340862842867548160, 90, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423189245956, 340862842867548160, 91, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423189245957, 340862842867548160, 92, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423193440258, 340862842867548160, 93, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423193440259, 340862842867548160, 94, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423193440260, 340862842867548160, 358, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423193440261, 340862842867548160, 359, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423193440262, 340862842867548160, 362, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423197634561, 340862842867548160, 363, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423197634562, 340862842867548160, 364, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423197634563, 340862842867548160, 365, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423197634564, 340862842867548160, 111, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423197634565, 340862842867548160, 112, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423201828866, 340862842867548160, 377, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423201828867, 340862842867548160, 378, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423201828868, 340862842867548160, 379, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423201828869, 340862842867548160, 380, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423201828870, 340862842867548160, 381, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423206023169, 340862842867548160, 382, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423206023170, 340862842867548160, 647, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423206023171, 340862842867548160, 648, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423206023172, 340862842867548160, 649, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423210217473, 340862842867548160, 400, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423210217474, 340862842867548160, 401, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423210217475, 340862842867548160, 402, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423214411778, 340862842867548160, 403, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423218606081, 340862842867548160, 404, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423218606082, 340862842867548160, 405, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423218606083, 340862842867548160, 406, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423222800385, 340862842867548160, 407, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423222800386, 340862842867548160, 408, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423222800387, 340862842867548160, 409, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423226994690, 340862842867548160, 410, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423226994691, 340862842867548160, 411, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423231188994, 340862842867548160, 414, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423231188995, 340862842867548160, 184, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423231188996, 340862842867548160, 185, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423231188997, 340862842867548160, 186, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423231188998, 340862842867548160, 462, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423235383298, 340862842867548160, 217, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423235383299, 340862842867548160, 218, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423235383300, 340862842867548160, 219, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423235383301, 340862842867548160, 220, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423235383302, 340862842867548160, 221, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423239577601, 340862842867548160, 222, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423239577602, 340862842867548160, 223, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423239577603, 340862842867548160, 225, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423239577604, 340862842867548160, 226, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423243771905, 340862842867548160, 227, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423243771906, 340862842867548160, 228, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423243771907, 340862842867548160, 229, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423243771908, 340862842867548160, 230, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423243771909, 340862842867548160, 231, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423247966210, 340862842867548160, 232, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423247966211, 340862842867548160, 233, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423247966212, 340862842867548160, 234, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423247966213, 340862842867548160, 235, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423247966214, 340862842867548160, 243, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423247966215, 340862842867548160, 244, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423252160514, 340862842867548160, 757, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423252160515, 340862842867548160, 245, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423252160516, 340862842867548160, 246, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423252160517, 340862842867548160, 758, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423252160518, 340862842867548160, 247, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423256354817, 340862842867548160, 248, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423256354818, 340862842867548160, 249, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423256354819, 340862842867548160, 250, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423256354820, 340862842867548160, 251, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423256354821, 340862842867548160, 252, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423256354822, 340862842867548160, 253, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423256354823, 340862842867548160, 254, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423260549121, 340862842867548160, 510, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423260549122, 340862842867548160, 255, 1);
INSERT INTO `sys_role_privilege` (`id`, `role_id`, `privilege_id`, `enable`) VALUES (1632627423260549123, 340862842867548160, 511, 1);
COMMIT;

-- ----------------------------
-- Table structure for sys_setting
-- ----------------------------
CREATE TABLE IF NOT EXISTS `sys_setting` (
           `id` bigint NOT NULL,
           `school_id` bigint NOT NULL COMMENT '学校Id',
           `parameter_object` varchar(2000) NOT NULL COMMENT '参数对象（json）',
           `create_id` bigint DEFAULT NULL COMMENT '创建人',
           `create_time` bigint DEFAULT NULL COMMENT '创建时间',
           `update_id` bigint DEFAULT NULL COMMENT '更新人',
           `update_time` bigint DEFAULT NULL COMMENT '更新时间',
           PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='系统设置';

-- ----------------------------
-- Table structure for sys_setting_global
-- ----------------------------
CREATE TABLE IF NOT EXISTS `sys_setting_global` (
          `id` bigint NOT NULL,
          `parameter_object` varchar(2000) NOT NULL COMMENT '参数对象（json）',
          `create_id` bigint DEFAULT NULL COMMENT '创建人',
          `create_time` bigint DEFAULT NULL COMMENT '创建时间',
          `update_id` bigint DEFAULT NULL COMMENT '更新人',
          `update_time` bigint DEFAULT NULL COMMENT '更新时间',
          PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb3 COMMENT='系统全局设置';

-- ----------------------------
-- Table structure for sys_user
-- ----------------------------
CREATE TABLE IF NOT EXISTS `sys_user` (
                `id` bigint NOT NULL COMMENT '主键',
                `school_id` bigint DEFAULT NULL COMMENT '学校id',
                `login_name` varchar(100) NOT NULL COMMENT '用户名',
                `real_name` varchar(100) NOT NULL COMMENT '姓名',
                `code` varchar(100) DEFAULT NULL COMMENT '工号',
                `password` varchar(50) NOT NULL COMMENT '密码',
                `mobile_number` varchar(11) DEFAULT NULL COMMENT '手机号',
                `org_id` bigint DEFAULT NULL COMMENT '机构id',
                `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                `pwd_count` tinyint DEFAULT '0' COMMENT '密码修改次数，默认为0',
                `pwd_update_time` bigint DEFAULT NULL COMMENT '密码修改时间',
                `remark` varchar(200) DEFAULT NULL COMMENT '备注',
                `create_id` bigint DEFAULT NULL COMMENT '创建人',
                `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                `update_id` bigint DEFAULT NULL COMMENT '修改人',
                `update_time` bigint DEFAULT NULL COMMENT '修改时间',
                `historic_name` varchar(100) DEFAULT NULL COMMENT '历史用户名称',
                `identify_area` varchar(300) DEFAULT NULL COMMENT '识别区域，坐标数组，可传多个',
                PRIMARY KEY (`id`) USING BTREE,
                UNIQUE KEY `user_schoolId_loginName_idx` (`school_id`,`login_name`) USING BTREE,
                UNIQUE KEY `uq_school_id_mobile_number` (`school_id`,`mobile_number`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='用户表';

-- ----------------------------
-- Records of sys_user
-- ----------------------------
INSERT INTO `sys_user` (`id`, `school_id`, `login_name`, `real_name`, `code`, `password`, `mobile_number`, `org_id`, `enable`, `pwd_count`, `pwd_update_time`, `remark`, `create_id`, `create_time`, `update_id`, `update_time`, `historic_name`, `identify_area`) VALUES (1, NULL, 'sysadmin', 'sysadmin', NULL, 'MTIzNDU2', NULL, NULL, 1, 1, 1629353956868, NULL, NULL, NULL, NULL, 1629353956881, NULL, NULL);

-- ----------------------------
-- Table structure for sys_user_role
-- ----------------------------
CREATE TABLE IF NOT EXISTS `sys_user_role` (
                 `id` bigint NOT NULL COMMENT '主键',
                 `user_id` bigint NOT NULL COMMENT '用户id',
                 `role_id` bigint NOT NULL COMMENT '角色id',
                 `privilege_id` bigint DEFAULT NULL COMMENT '权限id',
                 `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                 PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='用户和角色关联表';

-- ----------------------------
-- Records of sys_user_role
-- ----------------------------
INSERT INTO `sys_user_role` (`id`, `user_id`, `role_id`, `privilege_id`, `enable`) VALUES (1, 1, 1, NULL, 1);

-- ----------------------------
-- Table structure for t_b_session
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_b_session` (
               `id` varchar(100) NOT NULL COMMENT '主键',
               `school_id` bigint DEFAULT NULL COMMENT '学校id',
               `org_id` bigint DEFAULT NULL COMMENT '机构id',
               `identity` varchar(100) NOT NULL COMMENT '用户标识',
               `type` varchar(50) NOT NULL COMMENT '用户类型',
               `source` varchar(50) NOT NULL COMMENT '访问来源',
               `platform` varchar(50) NOT NULL COMMENT '设备分类',
               `device_id` varchar(100) NOT NULL COMMENT '设备标识',
               `address` varchar(100) NOT NULL COMMENT '登录IP地址',
               `access_token` varchar(50) NOT NULL COMMENT '访问令牌',
               `last_access_time` bigint DEFAULT NULL COMMENT '最近访问时间',
               `last_access_ip` varchar(100) DEFAULT NULL COMMENT '最近访问IP地址',
               `update_time` bigint DEFAULT NULL COMMENT '令牌更新时间',
               `expire_time` bigint DEFAULT NULL COMMENT '令牌强制失效时间',
               `app_source` varchar(50) DEFAULT NULL COMMENT '应用来源',
               PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='会话表';

-- ----------------------------
-- Table structure for t_b_task
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_b_task` (
                `id` bigint NOT NULL COMMENT '主键',
                `school_id` bigint DEFAULT NULL COMMENT '学校id',
                `org_id` bigint DEFAULT NULL COMMENT '机构id',
                `type` varchar(50) NOT NULL COMMENT '任务类型，USER_IMPORT：用户导入，\nQUESTION_MISSION_BATCH_CREATE：批量新建命题任务，\nSAMPLE_EXPORT：导出审核样本，\nPAPER_DOWNLOAD：卷库下载，\nEXAMINATION_IMPORT：考务数据导入，\nEXAMINATION_EXPORT：考务数据导出，\nPRINT_PDF_DOWNLOAD：批量下载pdf，\nCREATE_PDF：生成pdf，\nCOURSE_IMPORT：课程导入',
                `status` varchar(30) NOT NULL COMMENT '任务状态，INIT：未开始，RUNNING：进行中，FINISH：已完成',
                `summary` text COMMENT '实时摘要信息',
                `result` varchar(30) DEFAULT NULL COMMENT '数据结果，SUCCESS：成功，ERROR：失败',
                `import_file_name` varchar(100) DEFAULT NULL COMMENT '导入文件名',
                `import_file_path` varchar(500) DEFAULT NULL COMMENT '导入文件路径',
                `export_file_path` varchar(500) DEFAULT NULL COMMENT '导出文件路径',
                `txt_file_path` varchar(500) DEFAULT NULL COMMENT '报告路径',
                `remark` mediumtext COMMENT '备注',
                `create_id` bigint DEFAULT NULL COMMENT '创建人',
                `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                `update_id` bigint DEFAULT NULL COMMENT '更新人',
                `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='导入导出任务表';

-- ----------------------------
-- Table structure for t_s_auth
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_s_auth` (
            `id` bigint NOT NULL COMMENT '主键',
            `school_id` bigint NOT NULL COMMENT '学校id',
            `access_key` varchar(255) DEFAULT NULL COMMENT 'accessKey',
            `access_secret` varchar(255) DEFAULT NULL COMMENT 'accessSecret',
            `description` text COMMENT '离线授权证书',
            `type` varchar(16) NOT NULL COMMENT '授权类型',
            `create_id` bigint DEFAULT NULL COMMENT '创建人',
            `create_time` bigint DEFAULT NULL COMMENT '创建时间',
            `update_id` bigint DEFAULT NULL COMMENT '更新人',
            `update_time` bigint DEFAULT NULL COMMENT '更新时间',
            `expire_time` bigint DEFAULT NULL COMMENT '过期时间',
            `file` mediumblob COMMENT '文件数据',
            PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='激活授权配置表';

-- ----------------------------
-- Table structure for t_school_privilege
-- ----------------------------
CREATE TABLE IF NOT EXISTS `t_school_privilege` (
              `id` bigint NOT NULL COMMENT '主键',
              `school_id` bigint NOT NULL COMMENT '学校id',
              `privilege_id` bigint NOT NULL COMMENT '菜单权限id',
              PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='学校菜单权限表';
